"""..."""
# 导入顺序不能变, BaseClass 在前
# from .Config import *
from .Auth import Auth, aligo_config_folder, set_config_folder
from .BaseAligo import BaseAligo
from .Core import Core
from .Create import Create



"""..."""
# 必须在头部, 不能使用Pycharm的自动格式化
# from .Enum import *

from .AudioMeta import AudioMeta
from .AudioMusicMeta import AudioMusicMeta
from .AudioTranscodeTemplate import AudioTranscodeTemplate
from .BaseAlbum import BaseAlbum
from .BaseDrive import BaseDrive
from .BaseFile import BaseFile
from .BaseShareFile import BaseShareFile
from .BaseUser import BaseUser
from .CroppingBoundary import CroppingBoundary
from .CroppingSuggestionItem import CroppingSuggestionItem
from .DataClass import DataClass
from .DriveCapacityDetail import DriveCapacityDetail
from .DriveFile import DriveFile
from .EMailConfig import EMailConfig
from .FaceThumbnail import FaceThumbnail
from .FolderSizeInfo import FolderSizeInfo
from .ImageMedia import ImageMedia
from .ImageQuality import ImageQuality
from .ImageTag import ImageTag
from .ListAlbumItem import ListAlbumItem
from .LoginDevice import LoginDevice
from .LoginTimout import LoginTimeout
from .MediaTransCodeTemplate import MediaTransCodeTemplate
from .Null import Null
from .PersonalRightsInfo import PersonalRightsInfo
from .PersonalSpaceInfo import PersonalSpaceInfo
from .Privilege import Privilege
from .RateLimit import RateLimit
from .ShareLinkBaseFile import ShareLinkBaseFile
from .ShareLinkSchema import ShareLinkSchema
from .SystemTag import SystemTag
from .Token import Token
from .UploadPartInfo import UploadPartInfo
from .UserConfig import UserConfig
from .VideoMedia import VideoMedia
from .VideoMediaAudioStream import VideoMediaAudioStream
from .VideoMediaVideoStream import VideoMediaVideoStream
from .VideoPreview import VideoPreview
from .VideoPreviewPlayInfo import VideoPreviewPlayInfo
from .VideoPreviewSprite import VideoPreviewSprite
from .VideoTranscodeTemplate import VideoTranscodeTemplate
